@@ -54,9 +54,19 @@ def eval_pickled(f_s, args_s):
         get_logger(eval_pickled).error("got exception when unpickling f: {}".format(e))
         return DelayedException(e)
     try:
-        get_logger(f).info("start {}{} in process {}".format(f.__name__, args, os.getpid()))
+        if len(args) < 10:
+            get_logger(f).info("start {}{} in process {}".format(f.__name__, args, os.getpid()))
+        else:
+            get_logger(f).info("start {}({} args) in process {}".format(f.__name__, len(args), os.getpid()))
         result = f(*args)
-        get_logger(f).info("got result {!r} from process {}".format(result, os.getpid()))
+        try:
+            n = len(result)
+        except:
+            n = 0
+        if n < 10:
+            get_logger(f).info("got result {!r} from process {}".format(result, os.getpid()))
+        else:
+            get_logger(f).info("got result of len {} from process {}".format(n, os.getpid()))
         return result
     except Exception, e:
         get_logger(f).error("got exception: {}".format(e))
