@@ -1,4 +1,5 @@
 import logging
+import os
 
 
 def get_logger(obj=None):
@@ -23,4 +24,7 @@ def get_logger(obj=None):
         console_handler = logging.StreamHandler()
         console_handler.setFormatter(default_formatter)
         logger.addHandler(console_handler)
+        file_handler = logging.FileHandler("pacer%d.log" % os.getpid(), "a")
+        file_handler.setFormatter(default_formatter)
+        logger.addHandler(file_handler)
     return logger
